==> cdes-api-6.15.6-20250306.144527-3.jar: at/cdes/api/masterData/MasterDataPageInfo.java <==
/***********************************************************
 * $Id$
 * 
 * Copyright (C) 2002-2006 ev-i Informationstechnologie GmbH
 *
 * Created: 12.08.2023
 *
 * Author: wpausch/ev-i
 * 
 ***********************************************************/

package at.cdes.api.masterData;

import java.util.List;
import java.util.Map;

import at.cdes.api.dto.MasterDataSet;

public class MasterDataPageInfo {
    
    private Boolean enableCustomerLogo;
    private List<MasterDataSet> masterDataSets;
    
    private boolean mayEditDocumentTypes;
    private boolean mayEditDocumentNumberParts;
    private boolean mayEditOthers;
    
    private Map<Long, List<MasterDataItem>> msIdToDocumentTypeItems;
    private Map<Long, List<MasterDataItem>> msIdToSubProjectTypeItems;
    private Map<Long, List<MasterDataItem>> msIdToObjectTypeItems;
    private Map<Long, List<MasterDataItem>> msIdToDocumentNumberPartItems;
    private List<MasterDataItem> statutoryDutyItems;
    private List<MasterDataItem> personInChargeItems;
    private List<MasterDataItem> subjectAreaItems;

    public Boolean getEnableCustomerLogo() {
        return this.enableCustomerLogo;
    }

    public void setEnableCustomerLogo(Boolean enableCustomerLogo) {
        this.enableCustomerLogo = enableCustomerLogo;
    }

    public List<MasterDataSet> getMasterDataSets() {
        return this.masterDataSets;
    }

    public void setMasterDataSets(List<MasterDataSet> masterDataSets) {
        this.masterDataSets = masterDataSets;
    }
    
    public boolean isMayEditDocumentTypes() {
        return this.mayEditDocumentTypes;
    }

    public void setMayEditDocumentTypes(boolean mayEditDocumentTypes) {
        this.mayEditDocumentTypes = mayEditDocumentTypes;
    }

    public boolean isMayEditDocumentNumberParts() {
        return this.mayEditDocumentNumberParts;
    }

    public void setMayEditDocumentNumberParts(boolean mayEditDocumentNumberParts) {
        this.mayEditDocumentNumberParts = mayEditDocumentNumberParts;
    }

    public boolean isMayEditOthers() {
        return this.mayEditOthers;
    }

    public void setMayEditOthers(boolean mayEditOthers) {
        this.mayEditOthers = mayEditOthers;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToDocumentTypeItems() {
        return this.msIdToDocumentTypeItems;
    }

    public void setMsIdToDocumentTypeItems(Map<Long, List<MasterDataItem>> msIdToDocumentTypeItems) {
        this.msIdToDocumentTypeItems = msIdToDocumentTypeItems;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToSubProjectTypeItems() {
        return this.msIdToSubProjectTypeItems;
    }

    public void setMsIdToSubProjectTypeItems(Map<Long, List<MasterDataItem>> msIdToSubProjectTypeItems) {
        this.msIdToSubProjectTypeItems = msIdToSubProjectTypeItems;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToObjectTypeItems() {
        return this.msIdToObjectTypeItems;
    }

    public void setMsIdToObjectTypeItems(Map<Long, List<MasterDataItem>> msIdToObjectTypeItems) {
        this.msIdToObjectTypeItems = msIdToObjectTypeItems;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToDocumentNumberPartItems() {
        return this.msIdToDocumentNumberPartItems;
    }

    public void setMsIdToDocumentNumberPartItems(Map<Long, List<MasterDataItem>> msIdToDocumentNumberPartItems) {
        this.msIdToDocumentNumberPartItems = msIdToDocumentNumberPartItems;
    }

    public List<MasterDataItem> getStatutoryDutyItems() {
        return this.statutoryDutyItems;
    }

    public void setStatutoryDutyItems(List<MasterDataItem> statutoryDutyItems) {
        this.statutoryDutyItems = statutoryDutyItems;
    }

    public List<MasterDataItem> getPersonInChargeItems() {
        return this.personInChargeItems;
    }

    public void setPersonInChargeItems(List<MasterDataItem> personInChargeItems) {
        this.personInChargeItems = personInChargeItems;
    }

    public List<MasterDataItem> getSubjectAreaItems() {
        return this.subjectAreaItems;
    }

    public void setSubjectAreaItems(List<MasterDataItem> subjectAreaItems) {
        this.subjectAreaItems = subjectAreaItems;
    }
}

==> cdes-api-6.15.27-20250818.210450-1.jar: at/cdes/api/masterData/MasterDataPageInfo.java <==
/***********************************************************
 * $Id$
 * 
 * Copyright (C) 2002-2006 ev-i Informationstechnologie GmbH
 *
 * Created: 12.08.2023
 *
 * Author: wpausch/ev-i
 * 
 ***********************************************************/

package at.cdes.api.masterData;

import java.util.List;
import java.util.Map;

import at.cdes.api.dto.MasterDataSet;

public class MasterDataPageInfo {
    
    private Boolean enableCustomerLogo;
    private Boolean enablePlanningNotificationModul;
    private List<MasterDataSet> masterDataSets;
    
    private boolean mayEditDocumentTypes;
    private boolean mayEditDocumentNumberParts;
    private boolean mayEditOthers;
    
    private Map<Long, List<MasterDataItem>> msIdToDocumentTypeItems;
    private Map<Long, List<MasterDataItem>> msIdToSubProjectTypeItems;
    private Map<Long, List<MasterDataItem>> msIdToObjectTypeItems;
    private Map<Long, List<MasterDataItem>> msIdToDocumentNumberPartItems;
    private List<MasterDataItem> statutoryDutyItems;
    private List<MasterDataItem> personInChargeItems;
    private List<MasterDataItem> subjectAreaItems;

    public Boolean getEnableCustomerLogo() {
        return this.enableCustomerLogo;
    }

    public void setEnableCustomerLogo(Boolean enableCustomerLogo) {
        this.enableCustomerLogo = enableCustomerLogo;
    }

    public List<MasterDataSet> getMasterDataSets() {
        return this.masterDataSets;
    }

    public void setMasterDataSets(List<MasterDataSet> masterDataSets) {
        this.masterDataSets = masterDataSets;
    }
    
    public boolean isMayEditDocumentTypes() {
        return this.mayEditDocumentTypes;
    }

    public void setMayEditDocumentTypes(boolean mayEditDocumentTypes) {
        this.mayEditDocumentTypes = mayEditDocumentTypes;
    }

    public boolean isMayEditDocumentNumberParts() {
        return this.mayEditDocumentNumberParts;
    }

    public void setMayEditDocumentNumberParts(boolean mayEditDocumentNumberParts) {
        this.mayEditDocumentNumberParts = mayEditDocumentNumberParts;
    }

    public boolean isMayEditOthers() {
        return this.mayEditOthers;
    }

    public void setMayEditOthers(boolean mayEditOthers) {
        this.mayEditOthers = mayEditOthers;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToDocumentTypeItems() {
        return this.msIdToDocumentTypeItems;
    }

    public void setMsIdToDocumentTypeItems(Map<Long, List<MasterDataItem>> msIdToDocumentTypeItems) {
        this.msIdToDocumentTypeItems = msIdToDocumentTypeItems;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToSubProjectTypeItems() {
        return this.msIdToSubProjectTypeItems;
    }

    public void setMsIdToSubProjectTypeItems(Map<Long, List<MasterDataItem>> msIdToSubProjectTypeItems) {
        this.msIdToSubProjectTypeItems = msIdToSubProjectTypeItems;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToObjectTypeItems() {
        return this.msIdToObjectTypeItems;
    }

    public void setMsIdToObjectTypeItems(Map<Long, List<MasterDataItem>> msIdToObjectTypeItems) {
        this.msIdToObjectTypeItems = msIdToObjectTypeItems;
    }

    public Map<Long, List<MasterDataItem>> getMsIdToDocumentNumberPartItems() {
        return this.msIdToDocumentNumberPartItems;
    }

    public void setMsIdToDocumentNumberPartItems(Map<Long, List<MasterDataItem>> msIdToDocumentNumberPartItems) {
        this.msIdToDocumentNumberPartItems = msIdToDocumentNumberPartItems;
    }

    public List<MasterDataItem> getStatutoryDutyItems() {
        return this.statutoryDutyItems;
    }

    public void setStatutoryDutyItems(List<MasterDataItem> statutoryDutyItems) {
        this.statutoryDutyItems = statutoryDutyItems;
    }

    public List<MasterDataItem> getPersonInChargeItems() {
        return this.personInChargeItems;
    }

    public void setPersonInChargeItems(List<MasterDataItem> personInChargeItems) {
        this.personInChargeItems = personInChargeItems;
    }

    public List<MasterDataItem> getSubjectAreaItems() {
        return this.subjectAreaItems;
    }

    public void setSubjectAreaItems(List<MasterDataItem> subjectAreaItems) {
        this.subjectAreaItems = subjectAreaItems;
    }

	public Boolean getEnablePlanningNotificationModul() {
		return this.enablePlanningNotificationModul;
	}

	public void setEnablePlanningNotificationModul(Boolean enablePlanningNotificationModul) {
		this.enablePlanningNotificationModul = enablePlanningNotificationModul;
	}
}
